summaryrefslogtreecommitdiff
path: root/core/pim/todo/tableview.h
Side-by-side diff
Diffstat (limited to 'core/pim/todo/tableview.h') (more/less context) (ignore whitespace changes)
-rw-r--r--core/pim/todo/tableview.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/pim/todo/tableview.h b/core/pim/todo/tableview.h
index 528ddc9..7f78255 100644
--- a/core/pim/todo/tableview.h
+++ b/core/pim/todo/tableview.h
@@ -58,5 +58,5 @@ namespace Todo {
void updateView();
- void setTodo( int uid, const OTodo& );
- void addEvent( const OTodo& event );
- void replaceEvent( const OTodo& );
+ void setTodo( int uid, const OPimTodo& );
+ void addEvent( const OPimTodo& event );
+ void replaceEvent( const OPimTodo& );
void removeEvent( int uid );
@@ -74,3 +74,3 @@ namespace Todo {
* 40.000 QTableItems for 10.000
* OTodos where we only show 10 at a time!
*/
@@ -74,3 +74,3 @@ namespace Todo {
* 40.000 QTableItems for 10.000
- * OTodos where we only show 10 at a time!
+ * OPimTodos where we only show 10 at a time!
*/